@@ -6,7 +6,6 @@ use Baseobject;
 use Exporter;
 use Data::Dumper;
 $Data::Dumper::Indent = 1;
-use warnings FATAL=> 'all';
 
 use XML::LibXML;
 #use XML::LibXML::XPathContext;
@@ -17,18 +16,19 @@ use MIME::Base64;
 
 our @ISA=('Baseobject' );
 our @EXPORT = qw (verbosity);
-my $version ='$Id: Ldapsearch.pm 50026 2022-10-11 14:10:44Z anton $ ';
+my $version ='$Id: Ldapsearch.pm 43813 2015-09-07 10:59:23Z anton $ ';
 
+our $VERSION = "1.0";
 my $SELF;
 my $hierarchy = {};
-my $LDAP = {};
+my $LDAP;
 
 sub new {
 	my $pkg = shift;
 	my $self = bless (new Baseobject(@_),$pkg);
 	$SELF=$self;
 
-	$self->needs( [ qw (cfhash serverinfo) ] ) ;
+	$self->needs( [ qw (serverinfo cfhash) ] ) ;
 	
 	$self->allows ( { capath =>'/etc/ssl/certs' });
 	$self->allows ( [ qw ( binddn bindpwd)]);
@@ -36,8 +36,6 @@ sub new {
 	$self->fields(@_);
 	$self->checkneeds();
 
-#	$self->{fields}->{cfhash}->{serverinfo} = $self->{fields}->{serverinfo}; 
-	
 	$self->ldapinit() unless $self->error();
 	return $self;
 }
@@ -55,7 +53,7 @@ sub ldapsearch {
 		($self->{fields}->{cfhash}->{dumpldap}) ;
 
 	my $msg = $self->{ldap}->search(base   => $self->{base},
-									attrs => ['*', 'createTimestamp', 'modifyTimestamp', 'entryUUID'],
+									attrs => ['*', 'createTimestamp', 'modifyTimestamp'],
 									filter => $filter);
 
 	warn $self->inspect($msg) if $self->{fields}->{cfhash}->{dumpldap};
@@ -91,8 +89,8 @@ sub ldapinit {
 	warn ("type: $type, port: $port, base: $base, host: $host") if $self->{fields}->{cfhash}->{dumpldap};
 	$self->{base} = $base;
 
-	unless (exists $LDAP->{$host}) {
-		warn "Creating new ldap instance for host: $host"  if $self->{fields}->{cfhash}->{dumpldap};
+	unless (defined ($LDAP)) {
+		warn "CREATING NEW LDAP INSTANCE" if $self->{fields}->{cfhash}->{dumpldap};
 		if ($type eq 'ldaps') {
 			$self->{ldap}=Net::LDAPS->new(
 				$host,
@@ -113,10 +111,10 @@ sub ldapinit {
 			warn "Invalid url in serverinfo: \"$type\", should be ldaps:// or ldap://";
 			$self->error('invalid_serverinfo');
 		}
-		$LDAP->{$host} = $self->{ldap};
+		$LDAP = $self->{ldap};
 	} else {
-		warn "No new ldapinstance for host: $host" if $self->{fields}->{cfhash}->{dumpldap};
-		$self->{ldap}=$LDAP -> {$host};
+		warn "NO NEW LDAPINSTANCE" if $self->{fields}->{cfhash}->{dumpldap};
+		$self->{ldap}=$LDAP;
 	}
 
 	unless ($self->{ldap}) {
@@ -133,7 +131,7 @@ sub ldapinit {
 			password=>$self->{fields}->{bindpwd}
 			);
 		if ($msg->code) {
-			warn "error binding $self->{fields}->{binddn} on ldapserver: $type://$host pw: \"$self->{fields}->{bindpwd}\" ", $msg->error();
+			warn "error binding $self->{fields}->{binddn} on ldapserver: $type://$host", $msg->error();
 			$self->error($msg->error());
 		} else {
 			warn "BIND SUCCESSFUL FOR $self->{fields}->{binddn}, ldapserver: $host" if $self->{fields}->{cfhash}->{dumpldap};
@@ -267,12 +265,9 @@ sub translateorgname {
 	my $orgTree = $self->{fields}->{orgTree};
 	my @node;
 	my @res;
-	my $search = "//*[name=\"$orgname\"]";
+	my $search = "//*[\@name=\"$orgname\"]";
 	my $en;
 
-	return $orgname;
-
-
 	my $value = $orgname;
 	eval  {
 		(@node)=$orgTree->{doc}->findnodes("$search");
@@ -306,7 +301,7 @@ sub decodeOrgname {
 	my $orgTree = $self->{fields}->{orgTree};
 	my @node;
 
-	my $search = "//*[orgID=\"$orgID\"]";
+	my $search = "//*[\@orgID=\"$orgID\"]";
 
 	eval {
 		(@node) = $orgTree->{doc}->findnodes("$search");
@@ -316,13 +311,14 @@ sub decodeOrgname {
 	}
 	unless (@node)  {
 		warn "decodeOrgname: organisation not found: $orgID, search: $search";
+#	die $self->inspect($orgTree->{doc}->toString(2));
 		return $orgID;
 	}
 
 	die "decodeOrgname: Multiple organisations with orgID: $orgID" if @node > 1;
 	my $h;
-	$h->{name} = $node[0]->findvalue('name');
-	$h->{depth} = $node[0]->findvalue('depth');
+	$h->{name} = $node[0]->getAttribute('name');
+	$h->{depth} = $node[0]->getAttribute('depth');
 	return $h;
 }
 
@@ -492,7 +488,7 @@ sub addhierarchy {
 	# werkt echter nog niet op etch!
 	#  my $xc = new XML::LibXML::XPathContext;
 	#  $xc->registerVarLookupFunc(sub {$_[0]->{$_[1]}}, {name => $value});
-	my $search="//*[name=\"$value\"]";
+	my $search="//*[\@name=\"$value\"]";
 
 	eval {
 		#   (@node) = $xc->find('//*[@name=$search]', $orgTree->{doc});
@@ -518,7 +514,8 @@ sub addhierarchy {
 #		warn "node: " , $node->getAttribute('name');
 		unshift (@hierarchy, $parent);
 
-		while ($parent = $parent->parentNode and $parent = $parent->parentNode) {
+		while ($parent = $parent->parentNode) {
+			last unless $parent->parentNode();
 			unshift(@hierarchy, $parent);
 		}
 	}
@@ -526,11 +523,11 @@ sub addhierarchy {
 	my @hashlist = ();
 	foreach my $el (@hierarchy)	{
 		my $h;
-		my $name = $el->findvalue('name');
+		my $name = $el->getAttribute('name');
 		$h->{org} = $name;
 		$h->{display} = $name;
-		$h->{depth} = $el->findvalue('depth');
-		push(@hashlist,$h);
+		$h->{depth} = $el->getAttribute('depth');
+		push(@hashlist,$h) unless $name eq 'treeTop';
 	}
 	# Eindresultaat:
  	push (@{$hierarchy->{hierarchylist}}, \@hashlist) if @hashlist;
@@ -549,7 +546,7 @@ sub writehierarchy {
 
 	$self->output($parent, 'value','>', {
 		'hierarchy' => $name,
-				  }) if $name;
+				  }) ;
 
 	$self->output($parent,'value', $name, {
 		'href' => "?searchContext=$searchContext&ldapfilter=$ldapfilter",
